@@ -9,8 +9,7 @@ def FilterGenerator():
         def apply(self, mesh, filename):
             if os.path.exists(filename):
                 raise FilterException("specified filename already exists")
-            f = open(filename, 'w')
-            mesh.root.write(f)
-            f.close()
+            print "SAVING FILE"
+            mesh.write(filename)
             return mesh
     return ColladaSaveFilter()
